@@ -40,11 +40,12 @@ from praw.settings import CONFIG
 from requests.compat import urljoin
 from requests import Request
 from six.moves import html_entities, http_cookiejar
+from six.moves.urllib.parse import parse_qs, urlparse, urlunparse
 from update_checker import update_check
 from warnings import warn_explicit
 
 
-__version__ = '2.1.18'
+__version__ = '2.1.19'
 
 if os.environ.get('SERVER_SOFTWARE') is not None:
     # Google App Engine information
@@ -115,6 +116,7 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'login':               'api/login/',
                  'me':                  'api/v1/me',
                  'mentions':            'message/mentions',
+                 'messages':            'message/messages/',
                  'moderators':          'r/%s/about/moderators/',
                  'modlog':              'r/%s/about/log/',
                  'modqueue':            'r/%s/about/modqueue/',
@@ -146,7 +148,7 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'stylesheet':          'r/%s/about/stylesheet/',
                  'submit':              'api/submit/',
                  'sub_comments_gilded': 'r/%s/comments/gilded/',
-                 'sub_recommendations': 'api/subreddit_recommendations/',
+                 'sub_recommendations': 'api/recommend/sr/{0}',
                  'subreddit':           'r/%s/',
                  'subreddit_about':     'r/%s/about/',
                  'subreddit_comments':  'r/%s/comments/',
@@ -173,7 +175,7 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'wiki_pages':          'r/%s/wiki/pages/',
                  'wiki_banned':         'r/%s/about/wikibanned/',
                  'wiki_contributors':   'r/%s/about/wikicontributors/'}
-    SSL_PATHS = ('access_token_url', 'authorize', 'login')
+    SSL_PATHS = ('access_token_url', 'authorize', 'friends', 'login')
 
     def __init__(self, site_name, **kwargs):
         def config_boolean(item):
@@ -220,6 +222,8 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
         self.log_requests = int(obj['log_requests'])
         self.http_proxy = (obj.get('http_proxy') or os.getenv('http_proxy') or
                            None)
+        self.https_proxy = (obj.get('https_proxy') or os.getenv('https_proxy')
+                            or None)
         # We use `get(...) or None` because `get` may return an empty string
         self.client_id = obj.get('oauth_client_id') or None
         self.client_secret = obj.get('oauth_client_secret') or None
@@ -306,8 +310,12 @@ class BaseReddit(object):
         self.handler = handler or DefaultHandler()
         self.http = requests.session()  # Dummy session
         self.http.headers['User-Agent'] = UA_STRING % user_agent
-        if self.config.http_proxy:
-            self.http.proxies = {'http': self.config.http_proxy}
+        if self.config.http_proxy or self.config.https_proxy:
+            self.http.proxies = {}
+            if self.config.http_proxy:
+                self.http.proxies['http'] = self.config.http_proxy
+            if self.config.https_proxy:
+                self.http.proxies['https'] = self.config.https_proxy
         self.modhash = None
 
         # Check for updates if permitted and this is the first Reddit instance
@@ -505,7 +513,8 @@ class BaseReddit(object):
         :returns: JSON processed page
 
         """
-        url += '.json'
+        if not url.endswith('.json'):
+            url += '.json'
         if retry_on_error is None:
             response = self._request(url, params, data)
         else:
@@ -766,15 +775,18 @@ class UnauthenticatedReddit(BaseReddit):
 
     @decorators.restrict_access(scope='read')
     def get_info(self, url=None, thing_id=None, limit=None):
-        """Look up existing Submissions by thing_id (fullname) or url.
+        """Look up existing items by thing_id (fullname) or url.
 
         :param url: The url to lookup.
-        :param thing_id: The submission to lookup by fullname.
+        :param thing_id: A single thing_id, or a list of thing_ids. A thing_id
+            can be any one of Comment (t1_), Link (t3_), or Subreddit (t5_) to
+            lookup by fullname.
         :param limit: The maximum number of Submissions to return when looking
             up by url. When None, uses account default settings.
-        :returns: When thing_id is provided, return the corresponding
-            Submission object, or None if not found. When url is provided
-            return a list of Submission objects (up to limit) for the url.
+        :returns: When a single thing_id is provided, return the corresponding
+            thing object, or None if not found. When a list of thing_ids or a
+            url is provided return a list of thing objects (up to limit). None
+            is returned if any one of the thing_ids or the URL is invalid.
 
         """
         if bool(url) == bool(thing_id):
@@ -786,11 +798,14 @@ class UnauthenticatedReddit(BaseReddit):
             if limit:
                 params['limit'] = limit
         else:
+            if not isinstance(thing_id, six.string_types):
+                thing_id = ','.join(thing_id)
+                url = True  # Enable returning a list
             params = {'id': thing_id}
         items = self.request_json(self.config['info'],
                                   params=params)['data']['children']
         if url:
-            return items
+            return items if items else None
         elif items:
             return items[0]
         else:
@@ -940,7 +955,7 @@ class UnauthenticatedReddit(BaseReddit):
             return self.get_random_subreddit()
         return objects.Subreddit(self, subreddit_name, *args, **kwargs)
 
-    def get_subreddit_recommendations(self, subreddits, omitted=None):
+    def get_subreddit_recommendations(self, subreddits, omit=None):
         """Return a list of recommended subreddits as Subreddit objects.
 
         Subreddits with activity less than a certain threshold, will not have
@@ -948,13 +963,13 @@ class UnauthenticatedReddit(BaseReddit):
 
         :param subreddits: A list of subreddits (either names or Subreddit
             objects) to base the recommendations on.
-        :param omitted: A list of subreddits (either names or Subreddit
+        :param omit: A list of subreddits (either names or Subreddit
             objects) that will be filtered out of the result.
+
         """
-        omitted = omitted or []
-        params = {'srnames': _to_reddit_list(subreddits),
-                  'omitted': _to_reddit_list(omitted)}
-        result = self.request_json(self.config['sub_recommendations'],
+        params = {'omit': _to_reddit_list(omit or [])}
+        result = self.request_json(self.config['sub_recommendations']
+                                   .format(_to_reddit_list(subreddits)),
                                    params=params)
         return [objects.Subreddit(self, sub['sr_name']) for sub in result]
 
@@ -995,7 +1010,8 @@ class UnauthenticatedReddit(BaseReddit):
                period=None, *args, **kwargs):
         """Return a generator for submissions that match the search query.
 
-        :param query: The query string to search for.
+        :param query: The query string to search for. If query is a URL only
+            submissions which link to that URL will be returned.
         :param subreddit: Limit search results to the subreddit if provided.
         :param sort: The sort order of the results.
         :param syntax: The syntax of the search query.
@@ -1021,7 +1037,24 @@ class UnauthenticatedReddit(BaseReddit):
             url = self.config['search'] % subreddit
         else:
             url = self.config['search'] % 'all'
-        return self.get_content(url, params=params, *args, **kwargs)
+
+        depth = 2
+        while depth > 0:
+            depth -= 1
+            try:
+                for item in self.get_content(url, params=params, *args,
+                                             **kwargs):
+                    yield item
+                break
+            except errors.RedirectException as exc:
+                parsed = urlparse(exc.response_url)
+                params = dict((k, ",".join(v)) for k, v in
+                              parse_qs(parsed.query).items())
+                url = urlunparse(parsed[:3] + ("", "", ""))
+                # Handle redirects from URL searches
+                if 'already_submitted' in params:
+                    yield self.get_submission(url)
+                    break
 
     def search_reddit_names(self, query):
         """Return subreddits whose display name contains the query."""
@@ -1380,12 +1413,11 @@ class ModConfigMixin(AuthenticatedReddit):
                      content_options='any', over_18=False, default_set=True,
                      show_media=False, domain='', domain_css=False,
                      domain_sidebar=False, header_hover_text='',
-                     prev_description_id=None,
-                     prev_public_description_id=None, wikimode='disabled',
-                     wiki_edit_age=30, wiki_edit_karma=100,
+                     wikimode='disabled', wiki_edit_age=30,
+                     wiki_edit_karma=100,
                      submit_link_label='', submit_text_label='',
                      exclude_banned_modqueue=False, comment_score_hide_mins=0,
-                     public_traffic=False, prev_submit_text_id=None,
+                     public_traffic=False, collapse_deleted_comments=False,
                      spam_comments='low', spam_links='high',
                      spam_selfposts='high', submit_text='', **kwargs):
         """Set the settings for the given subreddit.
@@ -1395,21 +1427,21 @@ class ModConfigMixin(AuthenticatedReddit):
 
         """
         data = {'sr': subreddit.fullname,
-                'allow_top': 'on' if default_set else 'off',
+                'allow_top': default_set,
                 'comment_score_hide_mins': comment_score_hide_mins,
+                'collapse_deleted_comments': collapse_deleted_comments,
                 'description': description,
                 'domain': domain or '',
-                'domain_css': 'on' if domain_css else 'off',
-                'domain_sidebar': 'on' if domain_sidebar else 'off',
-                'exclude_banned_modqueue': ('on' if exclude_banned_modqueue
-                                            else 'off'),
+                'domain_css': domain_css,
+                'domain_sidebar': domain_sidebar,
+                'exclude_banned_modqueue': exclude_banned_modqueue,
                 'header-title': header_hover_text or '',
                 'lang': language,
                 'link_type': content_options,
-                'over_18': 'on' if over_18 else 'off',
+                'over_18': over_18,
                 'public_description': public_description,
                 'public_traffic': public_traffic,
-                'show_media': 'on' if show_media else 'off',
+                'show_media': show_media,
                 'submit_link_label': submit_link_label or '',
                 'submit_text': submit_text,
                 'submit_text_label': submit_text_label or '',
@@ -1421,12 +1453,7 @@ class ModConfigMixin(AuthenticatedReddit):
                 'wiki_edit_age': six.text_type(wiki_edit_age),
                 'wiki_edit_karma': six.text_type(wiki_edit_karma),
                 'wikimode': wikimode}
-        if prev_description_id is not None:
-            data['prev_description_id'] = prev_description_id
-        if prev_public_description_id is not None:
-            data['prev_public_description_id'] = prev_public_description_id
-        if prev_submit_text_id is not None:
-            data['prev_submit_text_id'] = prev_submit_text_id
+
         if kwargs:
             msg = 'Extra settings fields: {0}'.format(kwargs.keys())
             warn_explicit(msg, UserWarning, '', 0)
@@ -1436,7 +1463,7 @@ class ModConfigMixin(AuthenticatedReddit):
         return self.request_json(self.config['site_admin'], data=data)
 
     @decorators.restrict_access(scope='modconfig')
-    def set_stylesheet(self, subreddit, stylesheet, prevstyle=None):
+    def set_stylesheet(self, subreddit, stylesheet):
         """Set stylesheet for the given subreddit.
 
         :returns: The json response from the server.
@@ -1445,8 +1472,6 @@ class ModConfigMixin(AuthenticatedReddit):
         data = {'r': six.text_type(subreddit),
                 'stylesheet_contents': stylesheet,
                 'op': 'save'}  # Options: save / preview
-        if prevstyle is not None:
-            data['prevstyle'] = prevstyle
         self.evict(self.config['stylesheet'] % six.text_type(subreddit))
         return self.request_json(self.config['subreddit_css'], data=data)
 
@@ -1820,9 +1845,7 @@ class ModOnlyMixin(AuthenticatedReddit):
         return self.get_content(self.config['spam'] % six.text_type(subreddit),
                                 *args, **kwargs)
 
-    # OAuth scope modconfig for this method cannot be added until there has
-    # been an upstream change. See issue #174. Then the restriction will be
-    # @restrict_access('modconfig', mod=False, login=False)
+    @decorators.restrict_access('modconfig', mod=False, login=False)
     def get_stylesheet(self, subreddit):
         """Return the stylesheet and images for the given subreddit."""
         return self.request_json(self.config['stylesheet'] %
@@ -1940,12 +1963,13 @@ class PrivateMessagesMixin(AuthenticatedReddit):
         data = {'id': ','.join(thing_ids)}
         key = 'unread_message' if unread else 'read_message'
         response = self.request_json(self.config[key], data=data)
-        self.evict([self.config[x] for x in ['inbox', 'mod_mail', 'unread']])
+        self.evict([self.config[x] for x in ['inbox', 'messages',
+                                             'mod_mail', 'unread']])
         return response
 
     @decorators.restrict_access(scope='privatemessages')
     def get_inbox(self, *args, **kwargs):
-        """Return a get_content generator for inbox messages.
+        """Return a get_content generator for inbox (messages and comments).
 
         The additional parameters are passed directly into
         :meth:`.get_content`. Note: the `url` parameter cannot be altered.
@@ -1953,6 +1977,16 @@ class PrivateMessagesMixin(AuthenticatedReddit):
         """
         return self.get_content(self.config['inbox'], *args, **kwargs)
 
+    @decorators.restrict_access(scope='privatemessages')
+    def get_messages(self, *args, **kwargs):
+        """Return a get_content generator for inbox (messages only).
+
+        The additional parameters are passed directly into
+        :meth:`.get_content`. Note: the `url` parameter cannot be altered.
+
+        """
+        return self.get_content(self.config['messages'], *args, **kwargs)
+
     @decorators.restrict_access(scope='privatemessages')
     def get_sent(self, *args, **kwargs):
         """Return a get_content generator for sent messages.
