@@ -259,7 +259,6 @@ def restrict_access(scope, mod=None, login=None, oauth_only=False):
       * are called upon a RedditContent object with attribute subreddit
 
     """
-
     if not scope and oauth_only:
         raise TypeError('`scope` must be set when `oauth_only` is set')
 
@@ -291,8 +290,9 @@ def restrict_access(scope, mod=None, login=None, oauth_only=False):
                     # attribute to exist, thus it might not be set.
                     subreddit = cls if hasattr(cls, 'display_name') else False
                 else:
-                    subreddit = kwargs.get('subreddit', args[0] if args else
-                                           function.func_defaults[0])
+                    subreddit = kwargs.get(
+                        'subreddit', args[0] if args else
+                        six.get_function_defaults(function)[0])
             else:
                 subreddit = None
 
