@@ -70,8 +70,6 @@ class RedditContentObject(object):
         self.reddit_session = reddit_session
         self._underscore_names = underscore_names
         self.has_fetched = self._populate(json_dict, fetch)
-        self.json_dict = (json_dict if reddit_session.config.store_json_result
-                          is True else None)
 
     def __eq__(self, other):
         return (isinstance(other, RedditContentObject) and
@@ -127,9 +125,9 @@ class RedditContentObject(object):
     def _populate(self, json_dict, fetch):
         if json_dict is None:
             json_dict = self._get_json_dict() if fetch else {}
-            self.json_dict = (json_dict
-                              if self.reddit_session.config.store_json_result
-                              is True else None)
+        self.json_dict = (json_dict if
+                          self.reddit_session.config.store_json_result
+                          is True else None)
 
         # TODO: Remove this wikipagelisting hack
         if isinstance(json_dict, list):
@@ -391,14 +389,18 @@ class Reportable(RedditContentObject):
     """Interface for RedditContentObjects that can be reported."""
 
     @restrict_access(scope=None, login=True)
-    def report(self):
+    def report(self, reason=None):
         """Report this object to the moderators.
 
+        :param reason: The user-supplied reason for reporting a comment
+            or submission. Default: None (blank reason)
         :returns: The json response from the server.
 
         """
         url = self.reddit_session.config['report']
         data = {'id': self.fullname}
+        if reason:
+            data['reason'] = reason
         response = self.reddit_session.request_json(url, data=data)
         # Reported objects are automatically hidden as well
         # pylint: disable-msg=W0212
@@ -547,8 +549,8 @@ class Comment(Editable, Inboxable, Moderatable, Reportable, Voteable):
     @property
     def is_root(self):
         """Return True when the comment is a top level comment."""
-        return (self.parent_id is None or
-                self.parent_id == self.submission.fullname)
+        sub_prefix = self.reddit_session.config.by_object[Submission]
+        return self.parent_id.startswith(sub_prefix)
 
     @property
     def permalink(self):
@@ -685,12 +687,17 @@ class Redditor(Messageable, Refreshable):
         self.reddit_session.evict(self.reddit_session.config['friends'])
         return _modify_relationship('friend')(self.reddit_session.user, self)
 
-    def get_disliked(self):
-        """Return a listing of the things the user has downvoted.
+    def get_disliked(self, *args, **kwargs):
+        """Return a listing of the Submissions the user has downvoted.
+
+        :returns: get_content generator of Submission items.
+
+        The additional parameters are passed directly into
+        :meth:`.get_content`. Note: the `url` parameter cannot be altered.
 
         As a default, this listing is only accessible by the user. Thereby
-        requirering either user/pswd authentication or OAuth authentication
-        with the 'history' scope. Users may choose to make their voting record
+        requiring either user/pswd authentication or OAuth authentication with
+        the 'history' scope. Users may choose to make their voting record
         public by changing a user preference. In this case, no authentication
         will be needed to access this listing.
 
@@ -699,10 +706,16 @@ class Redditor(Messageable, Refreshable):
         # authenticated user. But who has a public voting record will be
         # successful.
         use_oauth = self.reddit_session.is_oauth_session()
-        return _get_redditor_listing('disliked')(self, _use_oauth=use_oauth)
+        return _get_redditor_listing('disliked')(
+            self, *args, _use_oauth=use_oauth, **kwargs)
 
-    def get_liked(self):
-        """Return a listing of the things the user has upvoted.
+    def get_liked(self, *args, **kwargs):
+        """Return a listing of the Submissions the user has upvoted.
+
+        :returns: get_content generator of Submission items.
+
+        The additional parameters are passed directly into
+        :meth:`.get_content`. Note: the `url` parameter cannot be altered.
 
         As a default, this listing is only accessible by the user. Thereby
         requirering either user/pswd authentication or OAuth authentication
@@ -712,7 +725,8 @@ class Redditor(Messageable, Refreshable):
 
         """
         use_oauth = self.reddit_session.is_oauth_session()
-        return _get_redditor_listing('liked')(self, _use_oauth=use_oauth)
+        return _get_redditor_listing('liked')(self, *args,
+                                              _use_oauth=use_oauth, **kwargs)
 
     def mark_as_read(self, messages, unread=False):
         """Mark message(s) as read or unread.
@@ -773,12 +787,7 @@ class LoggedInRedditor(Redditor):
         return self._mod_subs
 
     def get_friends(self):
-        """Return a UserList of Redditors with whom the user has friended.
-
-        Will throw a RedirectException while
-        https://github.com/praw-dev/praw/issues/175 is unresolved.
-
-        """
+        """Return a UserList of Redditors with whom the user has friended."""
         url = self.reddit_session.config['friends']
         return self.reddit_session.request_json(url)[0]
 
@@ -841,10 +850,11 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         :param params: dictionary containing extra GET data to put in the url.
 
         """
-        query_pairs = parse_qs(urlparse(url).query)
+        parsed = urlparse(url)
+        query_pairs = parse_qs(parsed.query)
         get_params = dict((k, ",".join(v)) for k, v in query_pairs.items())
         params.update(get_params)
-        url = urlunparse(urlparse(url)[:3] + ("", "", ""))
+        url = urlunparse(parsed[:3] + ("", "", ""))
         if comment_limit is None:  # Fetch MAX
             params['limit'] = 2048  # Just use a big number
         elif comment_limit > 0:  # Use value
@@ -941,7 +951,7 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         :returns: get_content generator iterating over Submission objects.
 
         The additional parameters are passed directly into
-        :meth:`.get_content`. Note: the `url` and `object_fileter` parameters
+        :meth:`.get_content`. Note: the `url` and `object_filter` parameters
         cannot be altered.
 
         """
