@@ -35,7 +35,7 @@ from six import text_type
 
 from praw import Reddit, decorators, errors, helpers, internal
 from praw.objects import (Comment, LoggedInRedditor, Message, MoreComments,
-                          Submission)
+                          Submission, Subreddit)
 
 USER_AGENT = 'PRAW_test_suite'
 
@@ -106,6 +106,7 @@ class BasicHelper(object):
 
         if self.r.config.is_reddit:
             self.comment_url = self.url('/r/redditdev/comments/dtg4j/')
+            self.link_id = 't3_dtg4j'
             self.link_url = self.url('/r/UCSantaBarbara/comments/m77nc/')
             self.link_url_link = 'http://imgur.com/Vr8ZZ'
             self.more_comments_url = self.url('/r/redditdev/comments/dqkfz/')
@@ -350,6 +351,10 @@ class BasicTest(unittest.TestCase, BasicHelper):
         result = self.r.get_top(limit=num, params={'t': 'all'})
         self.assertEqual(num, len(list(result)))
 
+    def test_info_by_id(self):
+        self.assertEqual(self.link_id,
+                         self.r.get_info(thing_id=self.link_id).fullname)
+
     def test_info_by_invalid_id(self):
         self.assertEqual(None, self.r.get_info(thing_id='INVALID'))
 
@@ -381,9 +386,41 @@ class BasicTest(unittest.TestCase, BasicHelper):
         self.assertRaises(TypeError, Reddit, user_agent='')
         self.assertRaises(TypeError, Reddit, user_agent=1)
 
+    def test_store_json_result(self):
+        self.r.config.store_json_result = True
+        sub_url = ('http://www.reddit.com/r/reddit_api_test/comments/'
+                   '1f7ojw/oauth_submit/')
+        sub = self.r.get_submission(url=sub_url)
+        self.assertEqual(sub.json_dict['url'], sub_url)
+
+    def test_store_lazy_json_result(self):
+        self.r.config.store_json_result = True
+        subreddit = self.r.get_subreddit(self.sr)
+        # Force object to load
+        subreddit.title
+        self.assertEqual(subreddit.json_dict['display_name'], self.sr)
+
+
+class SearchTest(unittest.TestCase, BasicHelper):
+    def setUp(self):
+        self.configure()
+
     @reddit_only
     def test_search(self):
-        self.assertTrue(list(self.r.search('test')))
+        self.assertTrue(len(list(self.r.search('test'))) > 2)
+
+    @reddit_only
+    def test_search_multiply_submitted_url(self):
+        self.assertTrue(
+            len(list(self.r.search('http://www.livememe.com/'))) > 2)
+
+    def test_search_reddit_names(self):
+        self.assertTrue(self.r.search_reddit_names('reddit'))
+
+    @reddit_only
+    def test_search_single_submitted_url(self):
+        self.assertEqual(
+            1, len(list(self.r.search('http://www.livememe.com/vg972qp'))))
 
     @reddit_only
     def test_search_with_syntax(self):
@@ -402,23 +439,6 @@ class BasicTest(unittest.TestCase, BasicHelper):
                                              period='all', limit=num)))
         self.assertTrue(submissions == num)
 
-    def test_search_reddit_names(self):
-        self.assertTrue(self.r.search_reddit_names('reddit'))
-
-    def test_store_json_result(self):
-        self.r.config.store_json_result = True
-        sub_url = ('http://www.reddit.com/r/reddit_api_test/comments/'
-                   '1f7ojw/oauth_submit/')
-        sub = self.r.get_submission(url=sub_url)
-        self.assertEqual(sub.json_dict['url'], sub_url)
-
-    def test_store_lazy_json_result(self):
-        self.r.config.store_json_result = True
-        subreddit = self.r.get_subreddit(self.sr)
-        # Force object to load
-        subreddit.title
-        self.assertEqual(subreddit.json_dict['display_name'], self.sr)
-
 
 class CacheTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
@@ -1347,6 +1367,8 @@ class OAuth2Test(unittest.TestCase, BasicHelper):
     def test_scope_modconfig(self):
         self.r.refresh_access_information(self.refresh_token['modconfig'])
         self.r.get_subreddit(self.sr).set_settings('foobar')
+        retval = self.r.get_subreddit(self.sr).get_stylesheet()
+        self.assertTrue('images' in retval)
 
     @reddit_only
     def test_scope_modflair(self):
@@ -1464,6 +1486,22 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
         self.configure()
         self.other_user = self.r.get_redditor(self.other_user_name)
 
+    def test_add_remove_friends(self):
+        def verify_add():
+            self.other_user.friend()
+            self.assertTrue(self.other_user in self.r.user.get_friends())
+
+        def verify_remove():
+            self.other_user.unfriend()
+            self.assertTrue(self.other_user not in self.r.user.get_friends())
+
+        if self.other_user in self.r.user.get_friends():
+            verify_remove()
+            verify_add()
+        else:
+            verify_add()
+            verify_remove()
+
     def test_duplicate_login(self):
         self.r.login(self.other_user_name, self.other_user_pswd)
 
@@ -1474,12 +1512,6 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
         self.delay()  # The queue needs to be processed
         self.assertFalse(item in self.r.user.get_liked())
 
-    def test_get_friends(self):
-        # See issue 175.
-        # If this test fails and doesn't raise an exception, but smoothly calls
-        # self.r.user.get_friends, then issue 175 has been resolved.
-        self.assertRaises(errors.RedirectException, self.r.user.get_friends)
-
     def test_get_hidden(self):
         submission = next(self.r.user.get_submitted())
         submission.hide()
@@ -1529,31 +1561,17 @@ class SettingsTest(unittest.TestCase, AuthenticatedHelper):
                           'INVALID CSS')
 
     def test_update_settings_description(self):
-        self.maxDiff = None
         settings = self.subreddit.get_settings()
         settings['description'] = 'Description %s' % uuid.uuid4()
         self.subreddit.update_settings(description=settings['description'])
-        new = self.subreddit.get_settings()
-        # The id should change, but nothing else
-        key = 'prev_description_id'
-        self.assertNotEqual(settings[key], new[key])
-        del settings[key]
-        del new[key]
-        self.assertEqual(settings, new)
+        self.assertEqual(settings, self.subreddit.get_settings())
 
     def test_update_settings_public_description(self):
-        self.maxDiff = None
         settings = self.subreddit.get_settings()
         settings['public_description'] = 'Description %s' % uuid.uuid4()
         self.subreddit.update_settings(
             public_description=settings['public_description'])
-        new = self.subreddit.get_settings()
-        # The id should change, but nothing else
-        key = 'prev_public_description_id'
-        self.assertNotEqual(settings[key], new[key])
-        del settings[key]
-        del new[key]
-        self.assertEqual(settings, new)
+        self.assertEqual(settings, self.subreddit.get_settings())
 
 
 class SubmissionCreateTest(unittest.TestCase, AuthenticatedHelper):
@@ -1668,14 +1686,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
         self.configure()
 
-    def test_clear_vote(self):
-        predicate = lambda submission: submission.likes is False
-        submission = self.first(self.r.user.get_submitted(), predicate)
-        submission.clear_vote()
-        # reload the submission
-        submission = self.r.get_submission(submission_id=submission.id)
-        self.assertEqual(submission.likes, None)
-
     def test_delete(self):
         submission = list(self.r.user.get_submitted())[-1]
         submission.delete()
@@ -1683,14 +1693,6 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         submission = self.r.get_submission(submission_id=submission.id)
         self.assertEqual(None, submission.author)
 
-    def test_downvote(self):
-        predicate = lambda submission: submission.likes is True
-        submission = self.first(self.r.user.get_submitted(), predicate)
-        submission.downvote()
-        # reload the submission
-        submission = self.r.get_submission(submission_id=submission.id)
-        self.assertEqual(submission.likes, False)
-
     def test_hide(self):
         self.disable_cache()
         predicate = lambda item: not item.hidden
@@ -1768,13 +1770,34 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
         submission = self.r.get_submission(submission_id=submission.id)
         self.assertFalse(submission.saved)
 
-    def test_upvote(self):
-        predicate = lambda submission: submission.likes is None
-        submission = self.first(self.r.user.get_submitted(), predicate)
-        submission.upvote()
-        # reload the submission
-        submission = self.r.get_submission(submission_id=submission.id)
-        self.assertEqual(submission.likes, True)
+    def test_voting(self):
+        def upvote():
+            submission.upvote()
+            self.r.evict(submission.permalink)
+            submission.refresh()
+            self.assertTrue(submission.likes)
+
+        def downvote():
+            submission.downvote()
+            self.r.evict(submission.permalink)
+            submission.refresh()
+            self.assertFalse(submission.likes)
+
+        def clear_vote():
+            submission.clear_vote()
+            self.r.evict(submission.permalink)
+            submission.refresh()
+            self.assertEqual(submission.likes, None)
+
+        submission = next(self.r.user.get_submitted())
+        if submission.likes:
+            downvote()
+            upvote()
+            clear_vote()
+        else:
+            upvote()
+            downvote()
+            clear_vote()
 
 
 class SubredditTest(unittest.TestCase, AuthenticatedHelper):
@@ -1816,8 +1839,9 @@ class SubredditTest(unittest.TestCase, AuthenticatedHelper):
         self.assertTrue(list(self.subreddit.search('test')))
 
     def test_get_subreddit_recommendations(self):
-        result = self.r.get_subreddit_recommendations('python')
+        result = self.r.get_subreddit_recommendations(['python', 'redditdev'])
         self.assertTrue(result)
+        self.assertTrue(all(isinstance(x, Subreddit) for x in result))
 
     def test_subscribe_and_verify(self):
         self.subreddit.subscribe()
